Neuron Reconstruction Tile Viewer

## layer Layer1

## structure VISl1

normalized_depth | 0.123824145
max_euclidean_distance | 168.0159233
cell_id | 555697303
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link

## structure VISp1

normalized_depth | 0.054725306
max_euclidean_distance | 102.789762
cell_id | 555341581
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.062175322
max_euclidean_distance | 165.4375967
cell_id | 594091004
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.074921291
max_euclidean_distance | 146.9441682
cell_id | 475585413
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.084501677
max_euclidean_distance | 99.21849503
cell_id | 523748610
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.09308737
max_euclidean_distance | 102.563929
cell_id | 562632795
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.094507209
max_euclidean_distance | 96.71589136
cell_id | 536951541
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.100175533
max_euclidean_distance | 118.1687743
cell_id | 564349611
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.124313438
max_euclidean_distance | 169.3049481
cell_id | 574734127
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.128893739
max_euclidean_distance | 63.02075206
cell_id | 555089724
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link

## structure VISpm1

normalized_depth | 0.030312596
max_euclidean_distance | 149.0805347
cell_id | 593321019
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.154216165
max_euclidean_distance | 152.4294622
cell_id | 593312584
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link

## layer Layer2

## structure FroL

normalized_depth | 0.098970826
max_euclidean_distance | 300.8253213
cell_id | 525133308
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link

## structure MTG

normalized_depth | 0.144430349
max_euclidean_distance | 496.7797154
cell_id | 529878215
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link

## layer Layer2/3

## structure VISal2/3

normalized_depth | 0.1407321
max_euclidean_distance | 274.0466313
cell_id | 584682764
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.160902535
max_euclidean_distance | 175.1572967
cell_id | 585841870
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.163924529
max_euclidean_distance | 201.637529
cell_id | 569072334
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.316098724
max_euclidean_distance | 366.9737061
cell_id | 487099387
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link

## structure VISam2/3

normalized_depth | 0.170744473
max_euclidean_distance | 239.597951
cell_id | 584680861
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link

## structure VISl2/3

normalized_depth | 0.128587693
max_euclidean_distance | 147.2624681
cell_id | 536306115
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link

## structure VISp2/3

normalized_depth | 0.109453902
max_euclidean_distance | 235.1067793
cell_id | 586559181
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.127481332
max_euclidean_distance | 428.0591935
cell_id | 517330781
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.142641293
max_euclidean_distance | 294.0467896
cell_id | 565863515
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.147883887
max_euclidean_distance | 156.8866983
cell_id | 585947309
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.151131112
max_euclidean_distance | 329.6292683
cell_id | 584254833
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.159964397
max_euclidean_distance | 194.7324115
cell_id | 585952606
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.161134337
max_euclidean_distance | 182.1846134
cell_id | 609435731
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.167472712
max_euclidean_distance | 149.468785
cell_id | 585832440
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.167739346
max_euclidean_distance | 146.9451395
cell_id | 554807924
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.171054957
max_euclidean_distance | 393.5383475
cell_id | 583138568
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.173199853
max_euclidean_distance | 316.3551106
cell_id | 487661754
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.180957804
max_euclidean_distance | 289.3170055
cell_id | 571306690
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.185149375
max_euclidean_distance | 134.0291643
cell_id | 566647353
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.186820624
max_euclidean_distance | 175.0537208
cell_id | 570896413
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.192572534
max_euclidean_distance | 213.2212282
cell_id | 614777438
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.192829221
max_euclidean_distance | 156.9155896
cell_id | 341442651
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.194667659
max_euclidean_distance | 309.5693955
cell_id | 583138230
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.196109723
max_euclidean_distance | 188.6852231
cell_id | 565866518
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.196510682
max_euclidean_distance | 330.6504816
cell_id | 585925172
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.19688809
max_euclidean_distance | 381.3827174
cell_id | 583146274
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.205923922
max_euclidean_distance | 188.5018836
cell_id | 585830272
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.20961962
max_euclidean_distance | 221.6939297
cell_id | 475623964
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.215495327
max_euclidean_distance | 324.8796594
cell_id | 587045566
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.217042709
max_euclidean_distance | 143.0903218
cell_id | 475068599
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.222854285
max_euclidean_distance | 238.712078
cell_id | 582613001
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.234108158
max_euclidean_distance | 362.8725588
cell_id | 586072188
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.234177407
max_euclidean_distance | 212.650735
cell_id | 567927838
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.239210513
max_euclidean_distance | 208.7043616
cell_id | 324493977
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.242932324
max_euclidean_distance | 209.4163011
cell_id | 574992320
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.243813028
max_euclidean_distance | 226.7227662
cell_id | 567952169
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.258569358
max_euclidean_distance | 298.6784276
cell_id | 502359001
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.259858926
max_euclidean_distance | 208.9603945
cell_id | 473540161
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.266963895
max_euclidean_distance | 182.756118
cell_id | 476686112
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.269880183
max_euclidean_distance | 157.5888883
cell_id | 539014038
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.27729055
max_euclidean_distance | 156.4240881
cell_id | 555345752
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.283241354
max_euclidean_distance | 390.9164975
cell_id | 565407476
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.299181113
max_euclidean_distance | 214.4663218
cell_id | 485184849
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.304307859
max_euclidean_distance | 140.815991
cell_id | 579626068
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.329211732
max_euclidean_distance | 330.3260362
cell_id | 582644266
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.332852705
max_euclidean_distance | 219.2711458
cell_id | 509515969
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.352679277
max_euclidean_distance | 140.5115424
cell_id | 473943881
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.354306507
max_euclidean_distance | 183.2507536
cell_id | 324266189
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.359625762
max_euclidean_distance | 431.3752421
cell_id | 382982932
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.363657225
max_euclidean_distance | 379.4671224
cell_id | 567007144
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.36671096
max_euclidean_distance | 342.3650153
cell_id | 502269786
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.369140405
max_euclidean_distance | 356.7985043
cell_id | 585946742
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.375081588
max_euclidean_distance | 221.9703878
cell_id | 488501071
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.390961108
max_euclidean_distance | 378.7346462
cell_id | 515315072
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.394036108
max_euclidean_distance | 276.3806934
cell_id | 565855793
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.397683456
max_euclidean_distance | 389.8543593
cell_id | 585944237
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.430576098
max_euclidean_distance | 324.7123934
cell_id | 563180078
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link

## structure VISpm2/3

normalized_depth | 0.100682372
max_euclidean_distance | 230.6527694
cell_id | 574059157
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.134307725
max_euclidean_distance | 193.2816798
cell_id | 586073683
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.159687214
max_euclidean_distance | 167.6434062
cell_id | 580145037
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.163384687
max_euclidean_distance | 174.2510376
cell_id | 571867358
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.163503015
max_euclidean_distance | 195.798163
cell_id | 586073850
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.171525997
max_euclidean_distance | 170.3436668
cell_id | 585805211
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.179607573
max_euclidean_distance | 229.5230079
cell_id | 585951863
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.213476477
max_euclidean_distance | 275.209523
cell_id | 586071425
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.24534939
max_euclidean_distance | 360.0332847
cell_id | 586072783
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link

## structure VISrl2/3

normalized_depth | 0.159575997
max_euclidean_distance | 201.9270557
cell_id | 614767057
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link

## layer Layer3

## structure FroL

normalized_depth | 0.161618547
max_euclidean_distance | 501.7144251
cell_id | 531517778
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link

## structure ITG

normalized_depth | 0.162400496
max_euclidean_distance | 464.5238462
cell_id | 529889679
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link

## structure MFG

normalized_depth | 0.189605199
max_euclidean_distance | 475.1618959
cell_id | 548440226
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.196190175
max_euclidean_distance | 480.0894456
cell_id | 548457754
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link

## structure MTG

normalized_depth | 0.148304811
max_euclidean_distance | 496.5912798
cell_id | 541540569
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.164933343
max_euclidean_distance | 521.0401143
cell_id | 508378649
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.181436803
max_euclidean_distance | 575.5542448
cell_id | 537266147
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.242224769
max_euclidean_distance | 420.9599818
cell_id | 529807751
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.254312811
max_euclidean_distance | 748.0636685
cell_id | 520631294
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.268243815
max_euclidean_distance | 279.2484066
cell_id | 541536216
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.290950641
max_euclidean_distance | 504.2537331
cell_id | 519832676
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.381666851
max_euclidean_distance | 199.7317296
cell_id | 601927090
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.388292563
max_euclidean_distance | 519.9298897
cell_id | 614230805
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link

## structure TemL

normalized_depth | 0.129711176
max_euclidean_distance | 454.4606912
cell_id | 526785799
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link

## layer Layer4

## structure MTG

normalized_depth | 0.438944364
max_euclidean_distance | 472.9040291
cell_id | 611610514
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.464551052
max_euclidean_distance | 288.9504
cell_id | 571427524
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.514497947
max_euclidean_distance | 1115.21477
cell_id | 601958555
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link

## structure VISam4

normalized_depth | 0.504206057
max_euclidean_distance | 284.9527573
cell_id | 580014328
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link

## structure VISl4

normalized_depth | 0.473813383
max_euclidean_distance | 381.5852542
cell_id | 588712191
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link

## structure VISp4

normalized_depth | 0.370210915
max_euclidean_distance | 370.7338559
cell_id | 560753350
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.37521152
max_euclidean_distance | 224.0842568
cell_id | 571379222
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.386679427
max_euclidean_distance | 207.5625913
cell_id | 574067499
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.40085817
max_euclidean_distance | 411.5954387
cell_id | 565209132
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.402635955
max_euclidean_distance | 238.439885
cell_id | 565415071
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.406953779
max_euclidean_distance | 215.8362379
cell_id | 565462089
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.425746551
max_euclidean_distance | 453.5506677
cell_id | 562003142
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.431092972
max_euclidean_distance | 226.6937231
cell_id | 573622646
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.446888231
max_euclidean_distance | 415.7819362
cell_id | 569809287
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.449950885
max_euclidean_distance | 98.47847188
cell_id | 560965993
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.462272657
max_euclidean_distance | 482.4913503
cell_id | 557998843
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.468929026
max_euclidean_distance | 188.121805
cell_id | 569723367
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.470184207
max_euclidean_distance | 152.3471971
cell_id | 554779051
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.504026088
max_euclidean_distance | 481.8272031
cell_id | 527826878
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.505794921
max_euclidean_distance | 234.5687521
cell_id | 565888394
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.517376276
max_euclidean_distance | 102.7771507
cell_id | 565417112
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link

## structure VISpm4

normalized_depth | 0.492963685
max_euclidean_distance | 307.7724431
cell_id | 565120091
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link

## structure VISpor4

normalized_depth | 0.514133178
max_euclidean_distance | 425.5604009
cell_id | 557874460
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link

## layer Layer5

## structure MTG

normalized_depth | 0.442203365
max_euclidean_distance | 379.8719011
cell_id | 528687520
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.533540474
max_euclidean_distance | 1054.738463
cell_id | 528042185
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.548023181
max_euclidean_distance | 339.7652322
cell_id | 571471295
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.591617879
max_euclidean_distance | 591.6332479
cell_id | 571666289
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.648476675
max_euclidean_distance | 1148.903715
cell_id | 537313158
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.751768658
max_euclidean_distance | 628.6874859
cell_id | 614197612
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link

## structure VISl5

normalized_depth | 0.553137767
max_euclidean_distance | 203.2666266
cell_id | 565459685
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.562273051
max_euclidean_distance | 218.6051738
cell_id | 509617624
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.588228313
max_euclidean_distance | 615.1974306
cell_id | 557864274
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.699367418
max_euclidean_distance | 232.1990664
cell_id | 562541627
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link

## structure VISli5

normalized_depth | 0.590227756
max_euclidean_distance | 110.448307
cell_id | 555019563
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.773809011
max_euclidean_distance | 588.6872238
cell_id | 603402458
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link

## structure VISp5

normalized_depth | 0.488758567
max_euclidean_distance | 410.8957648
cell_id | 599334696
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.489999725
max_euclidean_distance | 202.4499347
cell_id | 556923554
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.515895585
max_euclidean_distance | 423.2461105
cell_id | 584872371
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.516730792
max_euclidean_distance | 186.218009
cell_id | 591268268
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.52589921
max_euclidean_distance | 475.6965003
cell_id | 561532710
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.534861297
max_euclidean_distance | 581.3883548
cell_id | 478110866
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.551026597
max_euclidean_distance | 231.429096
cell_id | 572609108
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.555605135
max_euclidean_distance | 489.5548518
cell_id | 561553133
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.598847022
max_euclidean_distance | 576.3168652
cell_id | 589442285
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.603439845
max_euclidean_distance | 594.759881
cell_id | 557252022
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.607028097
max_euclidean_distance | 301.899745
cell_id | 517353438
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.60874864
max_euclidean_distance | 582.5221716
cell_id | 514824979
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.629589571
max_euclidean_distance | 216.0380343
cell_id | 569494755
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.639552174
max_euclidean_distance | 166.7449437
cell_id | 534303031
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.643479786
max_euclidean_distance | 376.6786552
cell_id | 561940338
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.646960786
max_euclidean_distance | 306.8113017
cell_id | 481136138
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.649004955
max_euclidean_distance | 418.460026
cell_id | 584231995
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.657026093
max_euclidean_distance | 496.7639133
cell_id | 607124114
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.66776021
max_euclidean_distance | 193.5749369
cell_id | 569958754
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.669481723
max_euclidean_distance | 273.3858626
cell_id | 547344442
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.669849463
max_euclidean_distance | 634.8876093
cell_id | 589760138
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.680746644
max_euclidean_distance | 244.7546112
cell_id | 574377552
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.698028371
max_euclidean_distance | 456.1019764
cell_id | 517345160
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.700967111
max_euclidean_distance | 211.6851075
cell_id | 575642695
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.702303079
max_euclidean_distance | 254.7967411
cell_id | 569998790
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.721684359
max_euclidean_distance | 261.9738591
cell_id | 592952680
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.723047165
max_euclidean_distance | 279.7005208
cell_id | 567312865
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.72609415
max_euclidean_distance | 162.4500577
cell_id | 475202388
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.728062877
max_euclidean_distance | 258.3525251
cell_id | 530737765
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.733370441
max_euclidean_distance | 209.695565
cell_id | 547262585
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.740826852
max_euclidean_distance | 296.215491
cell_id | 623185845
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.745565197
max_euclidean_distance | 317.4097653
cell_id | 555001065
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.755993177
max_euclidean_distance | 257.5360836
cell_id | 569965244
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.757310129
max_euclidean_distance | 171.9284649
cell_id | 321708130
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.772574937
max_euclidean_distance | 276.5595111
cell_id | 565880475
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link

## structure VISpm5

normalized_depth | 0.587938458
max_euclidean_distance | 188.8093473
cell_id | 580161872
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.760092159
max_euclidean_distance | 327.2802903
cell_id | 519749342
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link

## structure VISpor5

normalized_depth | 0.449532813
max_euclidean_distance | 396.698387
cell_id | 598628992
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.771628398
max_euclidean_distance | 670.0786889
cell_id | 589427435
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link

## layer Layer6a

## structure VISl6a

normalized_depth | 0.789974547
max_euclidean_distance | 575.6934962
cell_id | 507101551
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.841596989
max_euclidean_distance | 251.4988867
cell_id | 313862373
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link

## structure VISli6a

normalized_depth | 0.849192975
max_euclidean_distance | 291.1136443
cell_id | 555241040
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link

## structure VISp6a

normalized_depth | 0.729650686
max_euclidean_distance | 187.6695178
cell_id | 563226105
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.740877827
max_euclidean_distance | 243.0622645
cell_id | 583104750
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.745554114
max_euclidean_distance | 289.6081379
cell_id | 559387643
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.754214098
max_euclidean_distance | 170.7048502
cell_id | 554454458
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.766725253
max_euclidean_distance | 330.2109948
cell_id | 574036994
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.772326038
max_euclidean_distance | 298.1905412
cell_id | 586566174
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.778167659
max_euclidean_distance | 294.2430582
cell_id | 569723405
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.780029964
max_euclidean_distance | 314.294342
cell_id | 605660220
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.797264022
max_euclidean_distance | 215.1432244
cell_id | 488504814
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.804915924
max_euclidean_distance | 308.6433381
cell_id | 547325858
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.8080098
max_euclidean_distance | 391.9077929
cell_id | 574038330
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.811258316
max_euclidean_distance | 210.9130093
cell_id | 571396942
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.823739867
max_euclidean_distance | 121.8296717
cell_id | 560992553
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.83571114
max_euclidean_distance | 274.3789754
cell_id | 571311039
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.842580287
max_euclidean_distance | 774.282355
cell_id | 501847931
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.849529429
max_euclidean_distance | 239.2064254
cell_id | 517343484
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.851340208
max_euclidean_distance | 319.9667313
cell_id | 573404307
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.855084979
max_euclidean_distance | 286.2829417
cell_id | 570946690
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.857943696
max_euclidean_distance | 283.7431237
cell_id | 530731648
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.867021912
max_euclidean_distance | 357.3410581
cell_id | 580010290
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.867348891
max_euclidean_distance | 122.7596464
cell_id | 561985849
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.873803547
max_euclidean_distance | 270.803942
cell_id | 570896453
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.87871369
max_euclidean_distance | 305.7762478
cell_id | 516362762
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.890471795
max_euclidean_distance | 212.0107822
cell_id | 591278744
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.910887705
max_euclidean_distance | 907.7210142
cell_id | 557037024
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.911031053
max_euclidean_distance | 336.9407306
cell_id | 580162374
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.911951265
max_euclidean_distance | 312.5848332
cell_id | 580005568
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.917217873
max_euclidean_distance | 319.1018034
cell_id | 582917630
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.923006764
max_euclidean_distance | 103.1465951
cell_id | 578485753
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.933887602
max_euclidean_distance | 462.0009456
cell_id | 580007431
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.95550724
max_euclidean_distance | 425.4968792
cell_id | 578938153
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.970325689
max_euclidean_distance | 204.0484759
cell_id | 574993444
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link

## structure VISpor6a

normalized_depth | 0.850642457
max_euclidean_distance | 332.6652454
cell_id | 591265629
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link

## layer Layer6b

## structure VISp6b

normalized_depth | 0.957019062
max_euclidean_distance | 132.675053
cell_id | 579662957
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.964220271
max_euclidean_distance | 444.5687556
cell_id | 502383543
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.972346731
max_euclidean_distance | 432.3831096
cell_id | 502367941
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.981972216
max_euclidean_distance | 470.7882843
cell_id | 526643573
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link
normalized_depth | 0.987876221
max_euclidean_distance | 472.5553004
cell_id | 510136749
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link

## structure VISpl6b

normalized_depth | 0.927928958
max_euclidean_distance | 302.2598515
cell_id | 526668864
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link

## structure VISpm6b

normalized_depth | 0.973702951
max_euclidean_distance | 199.8986675
cell_id | 590558808
high_res_thumbnails | high_res_morphology_summary.png
20x_link | Link